@@ -36,64 +36,61 @@ const char xslmsg[] =
 "          });\n"
 "        </script>\n"
 "\n"
-"        <xsl:if test=\"system-property('xsl:vendor')!='Transformiix'\">\n"
-"          <!-- Non Mozilla specific markup -->\n"
-"          <script type=\"text/javascript\" src=\"https://www.google.com/jsapi\"/>\n"
-"          <script type=\"text/javascript\">\n"
+"        <script type=\"text/javascript\" src=\"https://www.google.com/jsapi\"/>\n"
+"        <script type=\"text/javascript\">\n"
+"          google.load(\"visualization\", \"1\", {packages:[\"corechart\"]});\n"
+"          google.setOnLoadCallback(loadGraphs);\n"
 "\n"
-"	    google.load(\"visualization\", \"1\", {packages:[\"corechart\"]});\n"
-"	    google.setOnLoadCallback(loadGraphs);\n"
+"          var graphs=[];\n"
 "\n"
-"	    var graphs=[];\n"
+"          function drawChart(chart_title,target,style,data) {\n"
+"            var data = google.visualization.arrayToDataTable(data);\n"
 "\n"
-"	    function drawChart(chart_title,target,style,data) {\n"
-"	      var data = google.visualization.arrayToDataTable(data);\n"
+"            var options = {\n"
+"              title: chart_title\n"
+"            };\n"
 "\n"
-"	      var options = {\n"
-"		title: chart_title\n"
-"	      };\n"
+"            var chart;\n"
+"            if (style == \"barchart\") {\n"
+"              chart = new google.visualization.BarChart(document.getElementById(target));\n"
+"              chart.draw(data, options);\n"
+"            } else if (style == \"piechart\") {\n"
+"              chart = new google.visualization.PieChart(document.getElementById(target));\n"
+"              chart.draw(data, options);\n"
+"            }\n"
+"          }\n"
 "\n"
-"	      var chart;\n"
-"	      if (style == \"barchart\") {\n"
-"		chart = new google.visualization.BarChart(document.getElementById(target));\n"
-"		chart.draw(data, options);\n"
-"	      } else if (style == \"piechart\") {\n"
-"		chart = new google.visualization.PieChart(document.getElementById(target));\n"
-"		chart.draw(data, options);\n"
-"	      }\n"
-"	    }\n"
+"          function loadGraphs(){\n"
+"            var g;\n"
 "\n"
-"	    function loadGraphs(){\n"
-"	      var g;\n"
+"            while (g = graphs.shift()) {\n"
+"              if (g.data.length > 1) {\n"
+"                drawChart(g.title,g.target,g.style,g.data);\n"
+"              }\n"
+"            }\n"
+"          }\n"
 "\n"
-"	      while(g = graphs.shift()){\n"
-"		// alert(\"going for: \" + g.target);\n"
-"		if(g.data.length > 1){\n"
-"		  drawChart(g.title,g.target,g.style,g.data);\n"
-"		}\n"
-"	      }\n"
-"	    }\n"
+"          <xsl:if test=\"server/counters[@type=&quot;qtype&quot;]/counter[. &gt; 0]\">\n"
+"            // Server Incoming Query Types\n"
+"            graphs.push({\n"
+"              'title' : \"Server Incoming Query Types\",\n"
+"              'target': 'chart_incoming_qtypes',\n"
+"              'style': 'barchart',\n"
+"              'data': [['Type','Counter'],<xsl:for-each select=\"server/counters[@type=&quot;qtype&quot;]/counter\">['<xsl:value-of select=\"@name\"/>',<xsl:value-of select=\".\"/>],</xsl:for-each>]\n"
+"            });\n"
+"          </xsl:if>\n"
 "\n"
-"	    <xsl:if test=\"server/counters[@type=&quot;qtype&quot;]/counter\">\n"
-"	      // Server Incoming Query Types\n"
-"	      graphs.push({\n"
-"			   'title' : \"Server Incoming Query Types\",\n"
-"			   'target': 'chart_incoming_qtypes',\n"
-"			   'style': 'barchart',\n"
-"			   'data': [['Type','Counter'],<xsl:for-each select=\"server/counters[@type=&quot;qtype&quot;]/counter\">['<xsl:value-of select=\"@name\"/>',<xsl:value-of select=\".\"/>],</xsl:for-each>]\n"
-"			   });\n"
-"	    </xsl:if>\n"
+"          <xsl:if test=\"server/counters[@type=&quot;opcode&quot;]/counter[. &gt; 0]\">\n"
+"            // Server Incoming Requests by opcode\n"
+"            graphs.push({\n"
+"              'title' : \"Server Incoming Requests by DNS Opcode\",\n"
+"              'target': 'chart_incoming_opcodes',\n"
+"              'style': 'barchart',\n"
+"              'data': [['Opcode','Counter'],<xsl:for-each select=\"server/counters[@type=&quot;opcode&quot;]/counter[. &gt; 0 or substring(@name,1,3) != 'RES']\">['<xsl:value-of select=\"@name\"/>',<xsl:value-of select=\".\"/>],</xsl:for-each>]\n"
+"            });\n"
+"          </xsl:if>\n"
+"        </script>\n"
 "\n"
-"	    <xsl:if test=\"server/counters[@type=&quot;opcode&quot;]/counter\">\n"
-"	      // Server Incoming Requests by opcode\n"
-"	      graphs.push({\n"
-"			   'title' : \"Server Incoming Requests by DNS Opcode\",\n"
-"			   'target': 'chart_incoming_opcodes',\n"
-"			   'style': 'barchart',\n"
-"			   'data': [['Opcode','Counter'],<xsl:for-each select=\"server/counters[@type=&quot;opcode&quot;]/counter[. &gt; 0 or substring(@name,1,3) != 'RES']\">['<xsl:value-of select=\"@name\"/>',<xsl:value-of select=\".\"/>],</xsl:for-each>]});\n"
-"	    </xsl:if>\n"
-"	  </script>\n"
-"        </xsl:if>\n"
 "        <style type=\"text/css\">\n"
 "     body {\n"
 "      font-family: sans-serif;\n"
@@ -338,13 +335,10 @@ const char xslmsg[] =
 "        </table>\n"
 "        <br/>\n"
 "        <xsl:if test=\"server/counters[@type=&quot;opcode&quot;]/counter[. &gt; 0]\">\n"
-"          <xsl:if test=\"system-property('xsl:vendor')!='Transformiix'\">\n"
-"            <h2>Incoming Requests by DNS Opcode</h2>\n"
-"            <!-- Non Mozilla specific markup -->\n"
-"            <div class=\"pie\" id=\"chart_incoming_opcodes\">\n"
-"	      [cannot display chart]\n"
-"	    </div>\n"
-"          </xsl:if>\n"
+"          <h2>Incoming Requests by DNS Opcode</h2>\n"
+"          <div class=\"pie\" id=\"chart_incoming_opcodes\">\n"
+"	    [cannot display chart]\n"
+"	  </div>\n"
 "          <table class=\"counters\">\n"
 "            <xsl:for-each select=\"server/counters[@type=&quot;opcode&quot;]/counter[. &gt; 0 or substring(@name,1,3) != 'RES']\">\n"
 "              <xsl:sort select=\".\" data-type=\"number\" order=\"descending\"/>\n"
@@ -372,14 +366,11 @@ const char xslmsg[] =
 "          </table>\n"
 "          <br/>\n"
 "        </xsl:if>\n"
-"        <xsl:if test=\"server/counters[@type=&quot;qtype&quot;]/counter\">\n"
-"          <xsl:if test=\"system-property('xsl:vendor')!='Transformiix'\">\n"
-"            <!-- Non Mozilla specific markup -->\n"
-"            <h3>Incoming Queries by Query Type</h3>\n"
-"            <div class=\"pie\" id=\"chart_incoming_qtypes\">\n"
-"	      [cannot display chart]\n"
-"	    </div>\n"
-"          </xsl:if>\n"
+"        <xsl:if test=\"server/counters[@type=&quot;qtype&quot;]/counter[. &gt; 0]\">\n"
+"          <h3>Incoming Queries by Query Type</h3>\n"
+"          <div class=\"pie\" id=\"chart_incoming_qtypes\">\n"
+"	    [cannot display chart]\n"
+"	  </div>\n"
 "          <table class=\"counters\">\n"
 "            <xsl:for-each select=\"server/counters[@type=&quot;qtype&quot;]/counter\">\n"
 "              <xsl:sort select=\".\" data-type=\"number\" order=\"descending\"/>\n"
@@ -411,21 +402,18 @@ const char xslmsg[] =
 "          <h2>Outgoing Queries per view</h2>\n"
 "          <xsl:for-each select=\"views/view[count(counters[@type=&quot;resqtype&quot;]/counter) &gt; 0]\">\n"
 "            <h3>View <xsl:value-of select=\"@name\"/></h3>\n"
-"            <xsl:if test=\"system-property('xsl:vendor')!='Transformiix'\">\n"
-"              <!-- Non Mozilla specific markup -->\n"
-"              <script type=\"text/javascript\">\n"
-"		  graphs.push({\n"
-"				'title': \"Outgoing Queries for view: <xsl:value-of select=\"@name\"/>\",\n"
-"				'target': 'chart_outgoing_queries_view_<xsl:value-of select=\"@name\"/>',\n"
-"				'style': 'barchart',\n"
-"				'data': [['Type','Counter'],<xsl:for-each select=\"counters[@type=&quot;resqtype&quot;]/counter\">['<xsl:value-of select=\"@name\"/>',<xsl:value-of select=\".\"/>],</xsl:for-each>]\n"
-"				});\n"
-"	      </script>\n"
-"              <xsl:variable name=\"target\">\n"
-"                <xsl:value-of select=\"@name\"/>\n"
-"              </xsl:variable>\n"
-"              <div class=\"pie\" id=\"chart_outgoing_queries_view_{$target}\">[no data to display]</div>\n"
-"            </xsl:if>\n"
+"            <script type=\"text/javascript\">\n"
+"	      graphs.push({\n"
+"                'title': \"Outgoing Queries for view: <xsl:value-of select=\"@name\"/>\",\n"
+"                'target': 'chart_outgoing_queries_view_<xsl:value-of select=\"@name\"/>',\n"
+"                'style': 'barchart',\n"
+"                'data': [['Type','Counter'],<xsl:for-each select=\"counters[@type=&quot;resqtype&quot;]/counter\">['<xsl:value-of select=\"@name\"/>',<xsl:value-of select=\".\"/>],</xsl:for-each>]\n"
+"	      });\n"
+"            </script>\n"
+"            <xsl:variable name=\"target\">\n"
+"              <xsl:value-of select=\"@name\"/>\n"
+"            </xsl:variable>\n"
+"            <div class=\"pie\" id=\"chart_outgoing_queries_view_{$target}\">[no data to display]</div>\n"
 "            <table class=\"counters\">\n"
 "              <xsl:for-each select=\"counters[@type=&quot;resqtype&quot;]/counter\">\n"
 "                <xsl:sort select=\".\" data-type=\"number\" order=\"descending\"/>\n"
@@ -450,18 +438,15 @@ const char xslmsg[] =
 "        </xsl:if>\n"
 "        <xsl:if test=\"server/counters[@type=&quot;nsstat&quot;]/counter[.&gt;0]\">\n"
 "          <h2>Server Statistics</h2>\n"
-"          <xsl:if test=\"system-property('xsl:vendor')!='Transformiix'\">\n"
-"            <!-- Non Mozilla specific markup -->\n"
 "            <script type=\"text/javascript\">\n"
-"		  graphs.push({\n"
-"				'title' : \"Server Counters\",\n"
-"				'target': 'chart_server_nsstat_restype',\n"
-"				'style': 'barchart',\n"
-"				'data': [['Type','Counter'],<xsl:for-each select=\"server/counters[@type=&quot;nsstat&quot;]/counter[.&gt;0]\">['<xsl:value-of select=\"@name\"/>',<xsl:value-of select=\".\"/>],</xsl:for-each>]\n"
-"				});\n"
-"	      </script>\n"
-"            <div class=\"pie\" id=\"chart_server_nsstat_restype\">[no data to display]</div>\n"
-"          </xsl:if>\n"
+"              graphs.push({\n"
+"                'title' : \"Server Counters\",\n"
+"                'target': 'chart_server_nsstat_restype',\n"
+"                'style': 'barchart',\n"
+"                'data': [['Type','Counter'],<xsl:for-each select=\"server/counters[@type=&quot;nsstat&quot;]/counter[.&gt;0]\">['<xsl:value-of select=\"@name\"/>',<xsl:value-of select=\".\"/>],</xsl:for-each>]\n"
+"              });\n"
+"            </script>\n"
+"          <div class=\"pie\" id=\"chart_server_nsstat_restype\">[no data to display]</div>\n"
 "          <table class=\"counters\">\n"
 "            <xsl:for-each select=\"server/counters[@type=&quot;nsstat&quot;]/counter[.&gt;0]\">\n"
 "              <xsl:sort select=\".\" data-type=\"number\" order=\"descending\"/>\n"
@@ -484,19 +469,16 @@ const char xslmsg[] =
 "          <br/>\n"
 "        </xsl:if>\n"
 "        <xsl:if test=\"server/counters[@type=&quot;zonestat&quot;]/counter[.&gt;0]\">\n"
-"          <xsl:if test=\"system-property('xsl:vendor')!='Transformiix'\">\n"
-"            <h2>Zone Maintenance Statistics</h2>\n"
-"            <script type=\"text/javascript\">\n"
-"		  graphs.push({\n"
-"				'title' : \"Zone Maintenance Stats\",\n"
-"				'target': 'chart_server_zone_maint',\n"
-"				'style': 'barchart',\n"
-"				'data': [['Type','Counter'],<xsl:for-each select=\"server/counters[@type=&quot;zonestat&quot;]/counter[.&gt;0]\">['<xsl:value-of select=\"@name\"/>',<xsl:value-of select=\".\"/>],</xsl:for-each>]\n"
-"				});\n"
-"	    </script>\n"
-"            <!-- Non Mozilla specific markup -->\n"
-"            <div class=\"pie\" id=\"chart_server_zone_maint\">[no data to display]</div>\n"
-"          </xsl:if>\n"
+"          <h2>Zone Maintenance Statistics</h2>\n"
+"          <script type=\"text/javascript\">\n"
+"            graphs.push({\n"
+"              'title' : \"Zone Maintenance Stats\",\n"
+"              'target': 'chart_server_zone_maint',\n"
+"              'style': 'barchart',\n"
+"              'data': [['Type','Counter'],<xsl:for-each select=\"server/counters[@type=&quot;zonestat&quot;]/counter[.&gt;0]\">['<xsl:value-of select=\"@name\"/>',<xsl:value-of select=\".\"/>],</xsl:for-each>]\n"
+"            });\n"
+"          </script>\n"
+"          <div class=\"pie\" id=\"chart_server_zone_maint\">[no data to display]</div>\n"
 "          <table class=\"counters\">\n"
 "            <xsl:for-each select=\"server/counters[@type=&quot;zonestat&quot;]/counter\">\n"
 "              <xsl:sort select=\".\" data-type=\"number\" order=\"descending\"/>\n"
@@ -788,22 +770,18 @@ const char xslmsg[] =
 "            <xsl:for-each select=\"zones/zone\">\n"
 "              <xsl:if test=\"counters[@type=&quot;qtype&quot;]/counter[count(.) &gt; 0]\">\n"
 "                <h4>Zone <xsl:value-of select=\"@name\"/></h4>\n"
-"                <xsl:if test=\"system-property('xsl:vendor')!='Transformiix'\">\n"
-"                  <!-- Non Mozilla specific markup -->\n"
-"                  <script type=\"text/javascript\">\n"
-"			graphs.push({\n"
-"				      'title': \"Query types for zone <xsl:value-of select=\"@name\"/>\",\n"
-"				      'target': 'chart_qtype_<xsl:value-of select=\"../../@name\"/>_<xsl:value-of select=\"@name\"/>',\n"
-"				      'style': 'barchart',\n"
-"				      'data': [['Type','Counter'],<xsl:for-each select=\"counters[@type=&quot;qtype&quot;]/counter[.&gt;0 and @name != &quot;QryAuthAns&quot;]\">['<xsl:value-of select=\"@name\"/>',<xsl:value-of select=\".\"/>],</xsl:for-each>]\n"
-"				      });\n"
-"\n"
-"		    </script>\n"
-"                  <xsl:variable name=\"target\">\n"
-"                    <xsl:value-of select=\"@name\"/>\n"
-"                  </xsl:variable>\n"
-"                  <div class=\"pie\" id=\"chart_qtype_{$thisview}_{$target}\">[no data to display]</div>\n"
-"                </xsl:if>\n"
+"                <script type=\"text/javascript\">\n"
+"                  graphs.push({\n"
+"                    'title': \"Query types for zone <xsl:value-of select=\"@name\"/>\",\n"
+"                    'target': 'chart_qtype_<xsl:value-of select=\"../../@name\"/>_<xsl:value-of select=\"@name\"/>',\n"
+"                    'style': 'barchart',\n"
+"                    'data': [['Type','Counter'],<xsl:for-each select=\"counters[@type=&quot;qtype&quot;]/counter[.&gt;0 and @name != &quot;QryAuthAns&quot;]\">['<xsl:value-of select=\"@name\"/>',<xsl:value-of select=\".\"/>],</xsl:for-each>]\n"
+"                  });\n"
+"                </script>\n"
+"                <xsl:variable name=\"target\">\n"
+"                  <xsl:value-of select=\"@name\"/>\n"
+"                </xsl:variable>\n"
+"                <div class=\"pie\" id=\"chart_qtype_{$thisview}_{$target}\">[no data to display]</div>\n"
 "                <table class=\"counters\">\n"
 "                  <xsl:for-each select=\"counters[@type=&quot;qtype&quot;]/counter\">\n"
 "                    <xsl:sort select=\".\"/>\n"
@@ -837,22 +815,18 @@ const char xslmsg[] =
 "            <xsl:for-each select=\"zones/zone\">\n"
 "              <xsl:if test=\"counters[@type=&quot;rcode&quot;]/counter[. &gt; 0]\">\n"
 "                <h4>Zone <xsl:value-of select=\"@name\"/></h4>\n"
-"                <xsl:if test=\"system-property('xsl:vendor')!='Transformiix'\">\n"
-"                  <!-- Non Mozilla specific markup -->\n"
-"                  <script type=\"text/javascript\">\n"
-"			graphs.push({\n"
-"				      'title': \"Response codes for zone <xsl:value-of select=\"@name\"/>\",\n"
-"				      'target': 'chart_rescode_<xsl:value-of select=\"../../@name\"/>_<xsl:value-of select=\"@name\"/>',\n"
-"				      'style': 'barchart',\n"
-"				      'data': [['Type','Counter'],<xsl:for-each select=\"counters[@type=&quot;rcode&quot;]/counter[.&gt;0 and @name != &quot;QryAuthAns&quot;]\">['<xsl:value-of select=\"@name\"/>',<xsl:value-of select=\".\"/>],</xsl:for-each>]\n"
-"				      });\n"
-"\n"
-"		</script>\n"
-"                  <xsl:variable name=\"target\">\n"
-"                    <xsl:value-of select=\"@name\"/>\n"
-"                  </xsl:variable>\n"
-"                  <div class=\"pie\" id=\"chart_rescode_{$thisview2}_{$target}\">[no data to display]</div>\n"
-"                </xsl:if>\n"
+"                <script type=\"text/javascript\">\n"
+"                  graphs.push({\n"
+"                    'title': \"Response codes for zone <xsl:value-of select=\"@name\"/>\",\n"
+"                    'target': 'chart_rescode_<xsl:value-of select=\"../../@name\"/>_<xsl:value-of select=\"@name\"/>',\n"
+"                    'style': 'barchart',\n"
+"                    'data': [['Type','Counter'],<xsl:for-each select=\"counters[@type=&quot;rcode&quot;]/counter[.&gt;0 and @name != &quot;QryAuthAns&quot;]\">['<xsl:value-of select=\"@name\"/>',<xsl:value-of select=\".\"/>],</xsl:for-each>]\n"
+"                  });\n"
+"                </script>\n"
+"                <xsl:variable name=\"target\">\n"
+"                  <xsl:value-of select=\"@name\"/>\n"
+"                </xsl:variable>\n"
+"                <div class=\"pie\" id=\"chart_rescode_{$thisview2}_{$target}\">[no data to display]</div>\n"
 "                <table class=\"counters\">\n"
 "                  <xsl:for-each select=\"counters[@type=&quot;rcode&quot;]/counter[.&gt;0 and @name != &quot;QryAuthAns&quot;]\">\n"
 "                    <xsl:sort select=\".\"/>\n"
